package com.six15.hudservice;
/*
  ******************************************************************************
  * @file    ${FILE_NAME}
  * @author  George Vigelette
  * @version v1.0.0
  * @date    6/06/2017
  * @brief
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2017 Duvitech</center></h2>
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  * 	struct hud_packet {
		uint8_t 	start;
		uint8_t		ctrl;
		uint16_t 	packet_len;
		uint32_t 	data_len;
		uint32_t 	data_crc;
		uint8_t* 	pData;
	};
*/
import android.util.Log;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

public class HudPacket {

    private static final String TAG = "[Six15]HUD_BASE_PACKET";

    HUD_StartBYTE _start;
    HUD_ControlBYTE _ctrl;
    short _packet_len;
    int _data_len;
    int _data_crc;

    ByteBuffer mData = null;


    public HudPacket() {

    }

    public short getPacketLen(){
        return _packet_len;
    }

    public HudPacket(byte[] bytes) {
        if(bytes == null || bytes.length <12){
            /* not a valid response packet */
            Log.e(TAG,"Not a valid Base packet");
            _start = HUD_StartBYTE.SB_ERROR;
            _ctrl = HUD_ControlBYTE.CB_ERROR;
            _packet_len = 0;
            _data_len = 0;
            _data_crc = 0;
            mData = null;
        }else {
            ByteBuffer buf = ByteBuffer.wrap(bytes);
            _start = HUD_StartBYTE.forValue(buf.get(0));
            _ctrl = HUD_ControlBYTE.forValue(buf.get(1));
            _packet_len = buf.order(ByteOrder.LITTLE_ENDIAN).getShort(2);
            _data_len = buf.order(ByteOrder.LITTLE_ENDIAN).getInt(4);
            _data_crc = buf.order(ByteOrder.LITTLE_ENDIAN).getInt(8);
            buf.position(12);
            if(_packet_len>0 && _packet_len<=500){
                mData = ByteBuffer.allocate(_data_len);
                mData.put(bytes, 12, _data_len);
            }
        }
    }

    public HUD_StartBYTE getStartCommandByte() {
        return _start;
    }

    public void setStartCommandByte(HUD_StartBYTE startCommand) {
        _start = startCommand;
    }

    public HUD_ControlBYTE getControlByte() {
        return _ctrl;
    }

    public void setControlByte(HUD_ControlBYTE controlByte) {
        _ctrl = controlByte;
    }

    public short getPacketDataLength() {
        return _packet_len;
    }

    public void setPacketDataLength(short length) {
        _packet_len = length;
    }

    public int getDataLength() {
        return _data_len;
    }

    public void setDataLength(int length){
        _data_len = length;
    }

    public int getCrc() {
        return _data_crc;
    }

    public void setCrc(int crc) {
        _data_crc = crc;
    }


    public void setData(byte[] data) throws IllegalAccessException{
        if(data.length > 500){
            throw new IllegalAccessException("Invalid Packet Size > 500");
        }
        mData = ByteBuffer.allocate(data.length);
        _data_len = data.length;
        mData.put(data);
    }

    public byte[] getData(){
        if(_packet_len>0 && mData != null && mData.array().length == _packet_len){
            return mData.array();
        }else{
            Log.e(TAG, "check mdata something is wrong");
        }

        return null;
    }
}
