package com.six15.hudservice;


/**
 * Created by gvige on 6/14/2017.
 *
 * 	typedef struct  {
 uint16_t 	id;
 uint8_t		cmd;
 uint8_t 	status;	 // success - 0x00 or failure - 0xff
 uint8_t 	err_code;
 uint8_t 	reserved;
 uint16_t 	data_len;
 uint32_t 	data_crc;
 uint8_t* 	pData;
 }typeHUD_RESPONSE;

 */

import android.util.Log;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;

public class HudResponsePacket {

    private static final String TAG = "[Six15]ResponsePacket" ;

    short _id;
    HUD_CommandBYTE _cmd;
    byte _status;
    HUD_ErrorBYTE _err;
    byte _reserved;
    short _len;
    int _crc;

    ByteBuffer mData = null;

    public HudResponsePacket(byte[] bytes) {

        if(bytes == null || bytes.length <12){
            /* not a valid response packet */
            Log.e(TAG,"Not a valid response packet");
            _id = 0;
            _cmd = HUD_CommandBYTE.HC_ERROR;
            _status = (byte)0xFF;
            _err = HUD_ErrorBYTE.HE_INVALID_PKT;
            _reserved = 0;
            _len = 0;
            _crc = 0;

            mData = null;
        }else {
            ByteBuffer buf = ByteBuffer.wrap(bytes);
            _id = buf.order(ByteOrder.LITTLE_ENDIAN).getShort(0);
            _cmd = HUD_CommandBYTE.forValue(buf.get(2));
            _status = buf.get(3);
            _err = HUD_ErrorBYTE.forValue(buf.get(4));
            _reserved = buf.get(5);
            _len = buf.order(ByteOrder.LITTLE_ENDIAN).getShort(6);
            _crc = buf.order(ByteOrder.LITTLE_ENDIAN).getInt(8);
            buf.position(12);
            if(_len>0){
                mData = ByteBuffer.allocate(_len);
                mData.put(bytes, 12, _len);
            }
        }
    }

    public short getID(){
        return _id;
    }

    public HUD_CommandBYTE getCommand(){
        return _cmd;
    }

    public byte getSatus(){
        return _status;
    }

    public HUD_ErrorBYTE getError(){
        return _err;
    }

    public byte getReserved(){
        return _reserved;
    }

    public short getDataLength(){
        return _len;
    }

    public  int getCrc(){
        return _crc;
    }

    public byte[] getData(){
        if(_len>0 && mData != null && mData.array().length == _len){
            return mData.array();
        }else{
            Log.e(TAG, "check mdata something is wrong");
        }

        return null;
    }
}
