package com.six15.six15presentationdemo;

import android.content.Context;
import android.hardware.display.DisplayManager;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Display;

public class MainActivity extends AppCompatActivity {

    private static final String TAG = "MainActivity";
    private DisplayManager mDisplayManager;
    private PresentSlide mPresentSlide = null;
    private static int hudDisplayID = -1;

    private final DisplayManager.DisplayListener mDisplayListener = new DisplayManager.DisplayListener() {
        @Override
        public void onDisplayAdded(int i) {
            Display display = mDisplayManager.getDisplay(i);
            if(display != null) {
                Log.d(TAG, "onDisplayAdded " + display.getName() + " ID: " + i);
                if (display.getName().compareTo("SIX-15 HUD") == 0) {
                    Log.d(TAG, "Found SIX-15 display enable presentation");

                }
            }
        }

        @Override
        public void onDisplayRemoved(int i) {
            Display display = mDisplayManager.getDisplay(i);
            Log.d(TAG, "onDisplayRemoved ID: " + i);
            if(i==hudDisplayID){
                Log.d(TAG, "Found SIX-15 display sending slide to it");
                if(mPresentSlide != null){
                    mPresentSlide.dismiss();
                    mPresentSlide = null;
                }
                hudDisplayID =  -1;
            }
        }

        @Override
        public void onDisplayChanged(int i) {
            Display display = mDisplayManager.getDisplay(i);
            if(display != null)
                Log.d(TAG, "onDisplayChanged " + display.getName() + " ID: " + i);
            else
                Log.d(TAG, "onDisplayChanged ID: " + i);
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.d(TAG,"onCreate");

        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mDisplayManager = (DisplayManager) getSystemService(Context.DISPLAY_SERVICE);
        mDisplayManager.registerDisplayListener(mDisplayListener,null);

    }

    @Override
    protected void onStart(){
        super.onStart();
        Log.d(TAG,"onStart");

        Display[] displays = mDisplayManager.getDisplays();
        for(int x = 0; x<displays.length; x++){
            Log.d(TAG, displays[x].getName());
            if(displays[x].getName().compareTo("SIX-15 HUD")==0){
                hudDisplayID = displays[x].getDisplayId();
                Log.d(TAG, "Found SIX-15 display sending slide to it ID: " + hudDisplayID);
                mPresentSlide = new PresentSlide(MainActivity.this, displays[x]);
            }
        }

    }

    @Override
    protected void onResume(){
        super.onResume();
        Log.d(TAG,"onResume");
        if(mPresentSlide != null)
            mPresentSlide.show();
    }

    @Override
    protected void onPause(){
        super.onPause();
        Log.d(TAG,"onPause");
    }

    @Override
    protected void onStop(){
        super.onStop();
        Log.d(TAG,"onStop");

        if (mPresentSlide != null) {
            mPresentSlide.dismiss();
            mPresentSlide = null;
        }
    }

    @Override
    protected void onDestroy(){
        super.onDestroy();
        Log.d(TAG,"onDestroy");
    }
}
